@@ -94,7 +94,7 @@ class UserProfile:
             else None,
             email=_dict.get("email"),
             img_url=_dict.get("img_url"),
-            push_notification_id=_dict.get("gcmId"),
+            push_notification_id=_dict.get("push_notification_id"),
             dob=datetime.fromisoformat(_dict["dob"]) if _dict.get("dob") else None,
             fb_access_token=_dict.get("fb_access_token"),
             user_types=_dict.get("user_types") or [],
