@@ -27,6 +27,7 @@ def test_dict_to_user_profile():
     assert "sample_work_address" == user_profile.work_address.location_name
     assert "sample_home_address" == user_profile.home_address.location_name
     assert "MALE" == user_profile.gender.name
+    assert "gcm-is-fcm-is-gcm" == user_profile.push_notification_id
 
 
 def test_dict_to_user_profile_for_incomplete_user_profile():
@@ -280,6 +281,7 @@ user_profile_dict = {
     "name": "sample_name",
     "zone_id": "b402e055-2884-43a1-9e33-dbfe67e62971",
     "updated_at": "2018-10-18T13:04:55.643673",
+    "push_notification_id": "gcm-is-fcm-is-gcm",
     "work_address": {
         "location": {"lat": 27.88, "lng": 76.33},
         "location_name": "sample_work_address",
