@@ -125,6 +125,18 @@ class UserService:
 
         self._raise_response_error(response)
 
+    def clear_all_sessions(self, phone_number: str):
+        response = requests.delete(
+            f"{self._authentication_url}/api/v1/sessions/clear_all_sessions",
+            json={"phone_number": phone_number},
+        )
+        if response.status_code == HTTPStatus.OK:
+            return response.json()["data"]
+        if response.status_code == HTTPStatus.NOT_FOUND:
+            raise NoSuchUser
+
+        self._raise_response_error(response)
+
     def attach_device(self, user_device: UserDevice):
         request_url = f"{self._profile_url}/api/v1/devices"
         request_json = user_device.to_dict()
